@@ -45,7 +45,11 @@ NO_VALIDATION_ERRORS_FOUND_MSG = BACKGROUND_BOLD_GREEN + "\n   No validation err
 
 
 def validate_data(
-    filepath: Path, creds: ServerCredentials, ignore_duplicate_files_warning: bool, save_graphs: bool
+    filepath: Path,
+    creds: ServerCredentials,
+    ignore_duplicate_files_warning: bool,
+    save_graphs: bool,
+    skip_ontology_validation: bool,
 ) -> bool:
     """
     Takes a file and project information and validates it against the ontologies on the server.
@@ -55,6 +59,7 @@ def validate_data(
         creds: server credentials for authentication
         ignore_duplicate_files_warning: ignore the shape that checks for duplicate files
         save_graphs: if this flag is set, all the graphs will be saved in a folder
+        skip_ontology_validation: skip the ontology validation
 
     Returns:
         True if no errors that impede an xmlupload were found.
@@ -70,6 +75,7 @@ def validate_data(
         severity=ValidationSeverity.INFO,
         ignore_duplicate_files_warning=ignore_duplicate_files_warning,
         is_on_prod_server=is_prod_like_server(creds.server),
+        skip_ontology_validation=skip_ontology_validation,
     )
     auth = AuthenticationClientLive(server=creds.server, email=creds.user, password=creds.password)
 
@@ -95,26 +101,14 @@ def validate_parsed_resources(
     config: ValidateDataConfig,
     auth: AuthenticationClient,
 ) -> bool:
-    ignore_duplicate_files = config.ignore_duplicate_files_warning
-    if not config.ignore_duplicate_files_warning:
-        duplicate_check = check_for_duplicate_files(parsed_resources, config)
-        if duplicate_check.user_msg:
-            logger.error(duplicate_check.user_msg)
-            print(f"{BACKGROUND_BOLD_RED}   Duplicate Filepaths Found!    {RESET_TO_DEFAULT}")
-            print(f"{BOLD_RED}{duplicate_check.user_msg}{RESET_TO_DEFAULT}")
-        if not duplicate_check.should_continue:
-            return False
-        ignore_duplicate_files = duplicate_check.duplicate_files_must_be_ignored
-
     rdf_graphs, used_iris = prepare_data_for_validation_from_parsed_resource(
         parsed_resources=parsed_resources,
         authorship_lookup=authorship_lookup,
         permission_ids=permission_ids,
         auth=auth,
         shortcode=shortcode,
-        ignore_duplicate_files_warning=ignore_duplicate_files,
     )
-    validation_result = _validate_data(rdf_graphs, used_iris, config)
+    validation_result = _validate_data(rdf_graphs, used_iris, parsed_resources, config)
     if validation_result.no_problems:
         logger.debug("No validation errors found.")
         print(NO_VALIDATION_ERRORS_FOUND_MSG)
@@ -140,19 +134,40 @@ def validate_parsed_resources(
         raise BaseError(f"Unknown validate data problems: {validation_result.problems!s}")
 
 
-def _validate_data(graphs: RDFGraphs, used_iris: set[str], config: ValidateDataConfig) -> ValidateDataResult:
+def _validate_data(
+    graphs: RDFGraphs,
+    used_iris: set[str],
+    parsed_resources: list[ParsedResource],
+    config: ValidateDataConfig,
+) -> ValidateDataResult:
     logger.debug(f"Validate-data called with the following config: {vars(config)}")
+    # Check if unknown classes are used
     if unknown_classes := check_for_unknown_resource_classes(graphs, used_iris):
         return ValidateDataResult(False, unknown_classes, None)
     shacl_validator = ShaclCliValidator()
-    onto_validation_result = validate_ontology(graphs.ontos, shacl_validator, config)
-    if onto_validation_result:
-        return ValidateDataResult(False, onto_validation_result, None)
+    if not config.skip_ontology_validation:
+        # Validation of the ontology
+        onto_validation_result = validate_ontology(graphs.ontos, shacl_validator, config)
+        if onto_validation_result:
+            return ValidateDataResult(False, onto_validation_result, None)
+    # Validation of the data
+    duplicate_file_warnings = None
+    if not config.ignore_duplicate_files_warning:
+        duplicate_file_warnings = check_for_duplicate_files(parsed_resources)
     report = get_validation_report(graphs, shacl_validator, config.save_graph_dir)
     if report.conforms:
-        return ValidateDataResult(True, None, None)
+        if not duplicate_file_warnings:
+            return ValidateDataResult(True, None, None)
+        else:
+            sorted_problems = SortedProblems(
+                unique_violations=[],
+                user_warnings=duplicate_file_warnings.problems,
+                user_info=[],
+                unexpected_shacl_validation_components=[],
+            )
+            return ValidateDataResult(False, sorted_problems, report)
     reformatted = reformat_validation_graph(report)
-    sorted_problems = sort_user_problems(reformatted)
+    sorted_problems = sort_user_problems(reformatted, duplicate_file_warnings)
     return ValidateDataResult(False, sorted_problems, report)
 
 
