@@ -6,7 +6,7 @@ from typing import Any
 
 from dsp_tools.error.xmllib_warnings import MessageInfo
 from dsp_tools.error.xmllib_warnings_util import emit_xmllib_input_warning
-from dsp_tools.error.xmllib_warnings_util import raise_input_error
+from dsp_tools.error.xmllib_warnings_util import raise_xmllib_input_error
 from dsp_tools.xmllib.internal.input_converters import check_and_fix_collection_input
 from dsp_tools.xmllib.internal.input_converters import check_and_fix_is_non_empty_string
 from dsp_tools.xmllib.models.config_options import NewlineReplacement
@@ -363,7 +363,7 @@ class RegionResource:
             ark: Original ARK in SALSAH
 
         Raises:
-            InputError: if metadata already exists
+            XmllibInputError: if metadata already exists
 
         Returns:
             The original region, with the added metadata
@@ -380,7 +380,7 @@ class RegionResource:
             msg_info = MessageInfo(
                 "This resource already contains migration metadata, no new data can be added.", resource_id=self.res_id
             )
-            raise_input_error(msg_info)
+            raise_xmllib_input_error(msg_info)
         self.migration_metadata = MigrationMetadata(creation_date=creation_date, iri=iri, ark=ark, res_id=self.res_id)
         return self
 
@@ -552,7 +552,7 @@ class LinkResource:
             ark: Original ARK in SALSAH
 
         Raises:
-            InputError: if metadata already exists
+            XmllibInputError: if metadata already exists
 
         Returns:
             The original resource, with the added metadata
@@ -569,7 +569,7 @@ class LinkResource:
             msg_info = MessageInfo(
                 "This resource already contains migration metadata, no new data can be added.", resource_id=self.res_id
             )
-            raise_input_error(msg_info)
+            raise_xmllib_input_error(msg_info)
         self.migration_metadata = MigrationMetadata(creation_date=creation_date, iri=iri, ark=ark, res_id=self.res_id)
         return self
 
@@ -1109,7 +1109,7 @@ class VideoSegmentResource:
             ark: Original ARK in SALSAH
 
         Raises:
-            InputError: if metadata already exists
+            XmllibInputError: if metadata already exists
 
         Returns:
             The original resource, with the added metadata
@@ -1126,7 +1126,7 @@ class VideoSegmentResource:
             msg_info = MessageInfo(
                 "This resource already contains migration metadata, no new data can be added.", resource_id=self.res_id
             )
-            raise_input_error(msg_info)
+            raise_xmllib_input_error(msg_info)
         self.migration_metadata = MigrationMetadata(creation_date=creation_date, iri=iri, ark=ark, res_id=self.res_id)
         return self
 
@@ -1632,7 +1632,7 @@ class AudioSegmentResource:
             ark: Original ARK in SALSAH
 
         Raises:
-            InputError: if metadata already exists
+            XmllibInputError: if metadata already exists
 
         Returns:
             The original resource, with the added metadata
@@ -1649,7 +1649,7 @@ class AudioSegmentResource:
             msg_info = MessageInfo(
                 "This resource already contains migration metadata, no new data can be added.", resource_id=self.res_id
             )
-            raise_input_error(msg_info)
+            raise_xmllib_input_error(msg_info)
         self.migration_metadata = MigrationMetadata(creation_date=creation_date, iri=iri, ark=ark, res_id=self.res_id)
         return self
 
