@@ -214,6 +214,30 @@ def test_xmlupload_default_validation_severity_error(xmlupload: Mock) -> None:
     )
 
 
+@patch("dsp_tools.cli.call_action.xmlupload")
+def test_xmlupload_skip_ontology_validation(xmlupload: Mock) -> None:
+    file = "filename.xml"
+    args = f"xmlupload {file} --skip-ontology-validation".split()
+    creds = ServerCredentials(
+        server="http://0.0.0.0:3333",
+        user="root@example.com",
+        password="test",
+        dsp_ingest_url="http://0.0.0.0:3340",
+    )
+    entry_point.run(args)
+    xmlupload.assert_called_once_with(
+        input_file=Path(file),
+        creds=creds,
+        imgdir=".",
+        config=UploadConfig(
+            skip_iiif_validation=False,
+            interrupt_after=None,
+            validation_severity=ValidationSeverity.INFO,
+            skip_ontology_validation=True,
+        ),
+    )
+
+
 @patch("dsp_tools.cli.call_action.xmlupload")
 def test_xmlupload_interrupt_after(xmlupload: Mock) -> None:
     file = "filename.xml"
@@ -239,7 +263,11 @@ def test_validate_data_default(validate_data: Mock) -> None:
         user="root@example.com", password="test", server="http://0.0.0.0:3333", dsp_ingest_url="http://0.0.0.0:3340"
     )
     validate_data.assert_called_once_with(
-        filepath=Path(file), save_graphs=False, creds=creds, ignore_duplicate_files_warning=False
+        filepath=Path(file),
+        save_graphs=False,
+        creds=creds,
+        ignore_duplicate_files_warning=False,
+        skip_ontology_validation=False,
     )
 
 
@@ -253,7 +281,11 @@ def test_validate_data_ignore_duplicate_files(validate_data: Mock) -> None:
         user="root@example.com", password="test", server="http://0.0.0.0:3333", dsp_ingest_url="http://0.0.0.0:3340"
     )
     validate_data.assert_called_once_with(
-        filepath=Path(file), save_graphs=False, creds=creds, ignore_duplicate_files_warning=True
+        filepath=Path(file),
+        save_graphs=False,
+        creds=creds,
+        ignore_duplicate_files_warning=True,
+        skip_ontology_validation=False,
     )
 
 
@@ -266,7 +298,11 @@ def test_validate_data_save_graph(validate_data: Mock) -> None:
         user="root@example.com", password="test", server="http://0.0.0.0:3333", dsp_ingest_url="http://0.0.0.0:3340"
     )
     validate_data.assert_called_once_with(
-        filepath=Path(file), save_graphs=True, creds=creds, ignore_duplicate_files_warning=False
+        filepath=Path(file),
+        save_graphs=True,
+        creds=creds,
+        ignore_duplicate_files_warning=False,
+        skip_ontology_validation=False,
     )
 
 
@@ -282,7 +318,11 @@ def test_validate_data_other_server(validate_data: Mock) -> None:
         dsp_ingest_url="https://ingest.dasch.swiss",
     )
     validate_data.assert_called_once_with(
-        filepath=Path(file), save_graphs=False, creds=creds, ignore_duplicate_files_warning=False
+        filepath=Path(file),
+        save_graphs=False,
+        creds=creds,
+        ignore_duplicate_files_warning=False,
+        skip_ontology_validation=False,
     )
 
 
@@ -298,7 +338,28 @@ def test_validate_data_other_creds(validate_data: Mock) -> None:
         user=user, password=password, server=server, dsp_ingest_url="https://ingest.test.dasch.swiss"
     )
     validate_data.assert_called_once_with(
-        filepath=Path(file), save_graphs=False, creds=creds, ignore_duplicate_files_warning=False
+        filepath=Path(file),
+        save_graphs=False,
+        creds=creds,
+        ignore_duplicate_files_warning=False,
+        skip_ontology_validation=False,
+    )
+
+
+@patch("dsp_tools.cli.call_action.validate_data")
+def test_validate_data_skip_ontology_validation(validate_data: Mock) -> None:
+    file = "filename.xml"
+    args = f"validate-data {file} --skip-ontology-validation".split()
+    entry_point.run(args)
+    creds = ServerCredentials(
+        user="root@example.com", password="test", server="http://0.0.0.0:3333", dsp_ingest_url="http://0.0.0.0:3340"
+    )
+    validate_data.assert_called_once_with(
+        filepath=Path(file),
+        save_graphs=False,
+        creds=creds,
+        ignore_duplicate_files_warning=False,
+        skip_ontology_validation=True,
     )
 
 
@@ -402,7 +463,11 @@ def test_ingest_xmlupload_localhost(ingest_xmlupload: Mock) -> None:
         dsp_ingest_url="http://0.0.0.0:3340",
     )
     ingest_xmlupload.assert_called_once_with(
-        xml_file=xml_file, creds=creds, interrupt_after=None, skip_validation=False
+        xml_file=xml_file,
+        creds=creds,
+        interrupt_after=None,
+        skip_validation=False,
+        skip_ontology_validation=False,
     )
 
 
@@ -418,7 +483,13 @@ def test_ingest_xmlupload_skip_validation(ingest_xmlupload: Mock) -> None:
         password="test",
         dsp_ingest_url="http://0.0.0.0:3340",
     )
-    ingest_xmlupload.assert_called_once_with(xml_file=xml_file, creds=creds, interrupt_after=None, skip_validation=True)
+    ingest_xmlupload.assert_called_once_with(
+        xml_file=xml_file,
+        creds=creds,
+        interrupt_after=None,
+        skip_validation=True,
+        skip_ontology_validation=False,
+    )
 
 
 @patch("dsp_tools.cli.call_action.ingest_xmlupload")
@@ -432,7 +503,9 @@ def test_ingest_xmlupload_interrupt_after(ingest_xmlupload: Mock) -> None:
         password="test",
         dsp_ingest_url="http://0.0.0.0:3340",
     )
-    ingest_xmlupload.assert_called_once_with(xml_file=xml_file, creds=creds, interrupt_after=1, skip_validation=False)
+    ingest_xmlupload.assert_called_once_with(
+        xml_file=xml_file, creds=creds, interrupt_after=1, skip_validation=False, skip_ontology_validation=False
+    )
 
 
 @patch("dsp_tools.cli.call_action.ingest_xmlupload")
@@ -450,7 +523,7 @@ def test_ingest_xmlupload_remote(ingest_xmlupload: Mock) -> None:
         dsp_ingest_url=server.replace("api", "ingest"),
     )
     ingest_xmlupload.assert_called_once_with(
-        xml_file=xml_file, creds=creds, interrupt_after=None, skip_validation=False
+        xml_file=xml_file, creds=creds, interrupt_after=None, skip_validation=False, skip_ontology_validation=False
     )
 
 
